@@ -1,32 +1,20 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Tobias Koenig <tokoe@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_BLOCKALARMSATTRIBUTE_H
 #define AKONADI_BLOCKALARMSATTRIBUTE_H
 
 #include "akonadi-calendar_export.h"
-#include <kcalendarcore/alarm.h>
+#include <KCalendarCore/Alarm>
 
 #include <attribute.h>
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short An Attribute that marks that alarms from a calendar collection are blocked.
  *
@@ -41,14 +29,14 @@ class AKONADI_CALENDAR_EXPORT BlockAlarmsAttribute : public Akonadi::Attribute
 {
 public:
     /**
-      * Creates a new block alarms attribute.
-      */
+     * Creates a new block alarms attribute.
+     */
     BlockAlarmsAttribute();
 
     /**
-      * Destroys the block alarms attribute.
-      */
-    ~BlockAlarmsAttribute();
+     * Destroys the block alarms attribute.
+     */
+    ~BlockAlarmsAttribute() override;
 
     /**
      * Blocks or unblocks given alarm type.
