@@ -11,17 +11,19 @@
 #include <KJob>
 #include <QUrl>
 
-namespace KIO {
+namespace KIO
+{
 class Job;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class FreeBusyDownloadJob : public KJob
 {
     Q_OBJECT
 public:
     explicit FreeBusyDownloadJob(const QUrl &url, QWidget *parentWidget = nullptr);
-    ~FreeBusyDownloadJob();
+    ~FreeBusyDownloadJob() override;
 
     void start() override;
 
